==> nextcloud-app-contacts-1.5.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/ia.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactos",
    "Download" : "Discargar",
    "ShowURL" : "Monstrar URL",
    "Share Addressbook" : "Compartir Adressario con alteres",
    "Delete Addressbook" : "Deler Adressario",
    "Share with users or groups" : "Compartir con usatores o gruppos",
    "Delete" : "Deler",
    "can edit" : "pote modificar",
    "Address book name" : "Nomine del adressario",
    "Import" : "Importar",
    "The selected image is too big (max 1MB)" : "Le imagine selectionate es troppo grande (maxime 1MG)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Iste carta es corrumpite e illo esseva reparate. Per favor, verifica le datos e salveguarda lo pro facer le cambios permanente.",
    "No contacts in here" : "Il ha nulle contactos ci.",
    "Name" : "Nomine",
    "Organization" : "Organisation",
    "Title" : "Titulo",
    "Add field ..." : "Adder campo ...",
    "Save changes" : "Salveguardar cambios",
    "No search result for {query}" : "Nulle resultato trovate pro {query}",
    "_%n contact_::_%n contacts_" : ["%n contacto","%n contactos"],
    "Post office box" : "Cassa postal",
    "Postal code" : "Codice postal",
    "City" : "Citate",
    "State or province" : "Stato o provincia",
    "Country" : "Pais",
    "Address" : "Adresse",
    "(new group)" : "(nove gruppo)",
    "Last name" : "Ultime nomine",
    "First name" : "Prime nomine",
    "Additional names" : "Nomines additional",
    "Prefix" : "Prefixo",
    "Suffix" : "Suffixo",
    "All contacts" : "Tote contactos",
    "Not grouped" : "Non gruppate",
    "New contact" : "Nove contacto",
    "{addressbook} shared by {owner}" : "{addressbook} compartite per {owner}",
    "Contact could not be created." : "Contacto non poteva esser create.",
    "No contacts in file. Only VCard files are allowed." : "Nulle contactos in file. Solmente files VCard es permittite.",
    "Only VCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Solmente VCard version 4.0 (RFC6350) o version 3.0 (RFC2426) es supportate.",
    "Nickname" : "Pseudonymo",
    "Detailed name" : "Nomine detaliate",
    "Notes" : "Notas",
    "Website" : "Sito web",
    "Federated Cloud ID" : "ID del Nube Federate",
    "Home" : "Domo",
    "Work" : "Travalio",
    "Other" : "Altere",
    "Groups" : "Gruppos",
    "Birthday" : "Anniversario de nativitate",
    "Anniversary" : "Anniversario de evento",
    "Date of death" : "Data de morte",
    "Email" : "E-posta",
    "Instant messaging" : "Messageria instantanee",
    "Phone" : "Phono",
    "Mobile" : "Mobile",
    "Fax" : "Fax",
    "Fax home" : "Fax a domicilio",
    "Fax work" : "Fax a travalio",
    "Pager" : "Pager",
    "Voice" : "Voce",
    "Social network" : "Medios Social",
    "Settings" : "Configurationes"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-contacts-2.1.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/ia.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactos",
    "Download" : "Discargar",
    "Delete" : "Deler",
    "Share with users or groups" : "Compartir con usatores o gruppos",
    "can edit" : "pote modificar",
    "Close" : "Clauder",
    "Copied!" : "Copiate!",
    "Not supported!" : "Non supportate!",
    "Press ⌘-C to copy." : "Pulsa ⌘-C pro copiar.",
    "Press Ctrl-C to copy." : "Pulsa Ctrl-C pro copiar.",
    "Address book name" : "Nomine del adressario",
    "The selected image is too big (max 1MB)" : "Le imagine selectionate es troppo grande (maxime 1MG)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Iste carta es corrumpite e illo esseva reparate. Per favor, verifica le datos e salveguarda lo pro facer le cambios permanente.",
    "No contacts in here" : "Nulle contactos ci.",
    "Name" : "Nomine",
    "Organization" : "Organisation",
    "Title" : "Titulo",
    "Save changes" : "Salveguardar cambios",
    "No search result for {query}" : "Nulle resultato trovate pro {query}",
    "All contacts" : "Tote contactos",
    "Post office box" : "Cassa postal",
    "Postal code" : "Codice postal",
    "City" : "Citate",
    "State or province" : "Stato o provincia",
    "Country" : "Pais",
    "Address" : "Adresse",
    "(new group)" : "(nove gruppo)",
    "Last name" : "Ultime nomine",
    "First name" : "Prime nomine",
    "Additional names" : "Nomines additional",
    "Prefix" : "Prefixo",
    "Suffix" : "Suffixo",
    "New contact" : "Nove contacto",
    "Not grouped" : "Non gruppate",
    "Sort by" : "Arrangiar per",
    "{addressbook} shared by {owner}" : "{addressbook} compartite per {owner}",
    "Contact could not be created." : "Contacto non poteva esser create.",
    "Display name" : "Monstrar nomine",
    "Nickname" : "Pseudonymo",
    "Detailed name" : "Nomine detaliate",
    "Notes" : "Notas",
    "Website" : "Sito web",
    "Federated Cloud ID" : "ID del Nube Federate",
    "Home" : "Domo",
    "Work" : "Travalio",
    "Other" : "Altere",
    "Groups" : "Gruppos",
    "Birthday" : "Anniversario de nativitate",
    "Anniversary" : "Anniversario de evento",
    "Date of death" : "Data de morte",
    "Email" : "E-posta",
    "Instant messaging" : "Messageria instantanee",
    "Phone" : "Phono",
    "Mobile" : "Mobile",
    "Fax" : "Fax",
    "Fax home" : "Fax a domicilio",
    "Fax work" : "Fax a travalio",
    "Pager" : "Pager",
    "Voice" : "Voce",
    "Social network" : "Medios Social",
    "Settings" : "Configurationes"
},
"nplurals=2; plural=(n != 1);");
